@@ -60,7 +60,6 @@ class McAfee(BaseAntivirus):
 
         # Invoke McAfee CLI.
         parameters = [
-            "START", "/B",
             "SCAN",
             "/ALL", "/SECURE", "/ALLOLE", "/STREAMS", "/DOHSM", "/MIME",
             "/NOBREAK", "/NOMEM", "/NOEXPIRE", "/RECURSIVE", "/SUB",
@@ -71,8 +70,8 @@ class McAfee(BaseAntivirus):
             "/THREADS", str(self._n_threads),
             "/SILENT",
         ]
-        completed = subprocess.Popen(parameters, shell=True)
-        # print(f"McAfee run completed with status code {completed.returncode}")
+        process = subprocess.Popen(parameters, shell=True)
+        process.wait()
 
         # Set self._bad_files based on files in badlist.
         if not os.path.exists(badlist):
